@@ -19,23 +19,41 @@ _define_list = typing.List[_define]
 _include_list = typing.List[_include]
 _opt_str = typing.Optional[str]
 
-
 class ExperienceType(Enum):
     CSYNTH_ONLY = 0
     SYNTHESIS = 1
     IMPLEMENTATION = 2
 
+def build_get_hls(exp):
+    pwd = str(Path().resolve())
+    def get_hl_files():
+        export_path = Path(f"./vivado_hls_synthesis/solution/syn/{exp._hdl.get_name()}/{exp._comp_name}.{exp._hdl.get_extension()}")
+        shutil.move(str(export_path.resolve()), str(pwd))
+    return get_hl_files
+
+def build_get_export_ip(exp):
+    pwd = str(Path().resolve())
+    def export_ip():
+        export_path = list(Path("./vivado_export/solution/impl/ip/").glob('*.zip'))[0]
+        shutil.move(str(export_path.resolve()), str(pwd))
+    return export_ip
+ 
+
 
 class HDL(Enum):
-    VHDL = (0, "vhdl")
-    VERILOG = (1, "verilog")
+    VHDL = (0, "vhdl", "vhd")
+    VERILOG = (1, "verilog", "v")
 
     def __init__(self, *vals):
         self._name = vals[1]
+        self._extension = vals[2]
 
     def get_name(self):
         return self._name
 
+    def get_extension(self):
+        return self._extension
+
 
 class Experiment:
     def __init__(self,
@@ -72,6 +90,7 @@ class Experiment:
         self._syn_impl_res = None
         self._keep_env = keep_env
         self._exp_name = exp_name
+        self._before_del_lst = []
 
     @property
     def clock_period(self):
@@ -81,6 +100,9 @@ class Experiment:
     def name(self):
         return self._exp_name
 
+    def add_before_del(self, callback):
+        self._before_del_lst.append(callback)
+
     def add_includes(self, includes: _include_list):
         self._includes.extend(includes)
 
@@ -118,8 +140,7 @@ class Experiment:
 
     def run_exp(self, 
                 depth_constraint: typing.Optional[int] = None, 
-                suffix: str="", 
-                before_del = None
+                suffix: str=""
                ):
         logger = self._logger
         logger.info(f"Experiment: {self._exp_name}{suffix}")
@@ -151,8 +172,8 @@ class Experiment:
                                      f'{self._comp_name}_timing_{report_suffix_to_use}.rpt').resolve()
                 self._syn_impl_res = vrpt.parse_impl_report(vivado_report, vivado_timing_rpt)
 
-            if before_del is not None:
-                befor_del()
+            for callback in self._before_del_lst:
+                callback()
         return self
 
     def get_results(self):
