@@ -50,7 +50,7 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
     file.write('set_directive_interface -mode ap_ctrl_none [get_top]\n')
     file.write('config_schedule -relax_ii_for_timing=0 -effort high\n')
     file.write('set_directive_inline -recursive [get_top]\n')
-    if pipeline and (depth_constraint is None or depth_constraint >= 1):
+    if pipeline and (depth_constraint is None or depth_constraint > 1):
         file.write('set_directive_pipeline -II 1 [get_top]\n')
     if depth_constraint is not None:
         file.write('set_directive_latency -min {} -max {} [get_top]\n'.format(depth_constraint, depth_constraint))
